@@ -37,4 +37,12 @@ pub fn get_cert_duration_left(x509_cert : &[u8]) -> Result<Duration,()> {
     let valid_secs = (valid_until - since_the_epoch.as_secs()).max(0);
     let wait_secs = Duration::from_secs(valid_secs as u64);
     Ok(wait_secs)
-}
\ No newline at end of file
+}
+
+#[cfg(not(any(feature = "use_rustls", feature = "use_openssl")))]
+mod dummy;
+#[cfg(not(any(feature = "use_rustls", feature = "use_openssl")))]
+pub use self::dummy::{EcdsaP256SHA256KeyPair,
+    sha256_hasher, sha256,
+    gen_acme_cert, CertBuilder};
+
